@@ -1,5 +1,8 @@
 //! Process-associated operations.
 
+use crate::imp;
+use std::os::raw::c_int;
+
 #[cfg(not(target_os = "wasi"))] // WASI doesn't have get[gpu]id.
 mod id;
 mod sched;
@@ -11,23 +14,9 @@ pub use sched::sched_yield;
 /// `EXIT_SUCCESS` for use with [`exit`].
 ///
 /// [`exit`]: std::process::exit
-#[cfg(libc)]
-pub use libc::EXIT_SUCCESS;
-
-/// `EXIT_SUCCESS` for use with [`exit`].
-///
-/// [`exit`]: std::process::exit
-#[cfg(linux_raw)]
-pub const EXIT_SUCCESS: std::os::raw::c_int = 0;
+pub const EXIT_SUCCESS: c_int = imp::process::EXIT_SUCCESS;
 
 /// `EXIT_FAILURE` for use with [`exit`].
 ///
 /// [`exit`]: std::process::exit
-#[cfg(libc)]
-pub use libc::EXIT_FAILURE;
-
-/// `EXIT_FAILURE` for use with [`exit`].
-///
-/// [`exit`]: std::process::exit
-#[cfg(linux_raw)]
-pub const EXIT_FAILURE: std::os::raw::c_int = 1;
+pub const EXIT_FAILURE: c_int = imp::process::EXIT_FAILURE;
